@@ -16,13 +16,13 @@
 # Template processing is supported by Doc_Subst.
 #
 # Stephen Uhler / Brent Welch (c) 1997-1998 Sun Microsystems
-# Brent Welch (c) 1999 Scriptics Corporation
+# Brent Welch (c) 1998-2000 Ajuba Solutions
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
-# SCCS: @(#) doc.tcl 1.20 97/08/05 15:02:32
+# RCS: @(#) $Id: doc.tcl,v 1.37 2000/09/02 00:40:45 welch Exp $
 
-package provide doc 1.1
+package provide httpd::doc 1.0
 
 # Query or set the physical pathname of the document root
 proc Doc_Root {{real {}}} {
@@ -244,6 +244,11 @@ proc DocDomain {virtual directory sock suffix} {
 
     set pathlist $data(pathlist)
 
+    # Suffix may have URL encoded things in it - this has a already
+    # been decoded into pathlist
+
+    set suffix [join $pathlist /]
+
     # Check for personal home pages
 
     if {[regexp ^~ $pathlist] && [info exists Doc(homedir)]} {
@@ -259,7 +264,11 @@ proc DocDomain {virtual directory sock suffix} {
 
     # Handle existing files
 
-    set path [file join $directory [string trimleft $suffix /]]
+    # The file join here is subject to attacks that create absolute
+    # pathnames outside the URL tree.  We trim left the / and ~
+    # to prevent those attacks.
+
+    set path [file join $directory [string trimleft $suffix /~]]
     if {[file exists $path]} {
 	Incr Doc(hit,$data(url))
 	DocHandle $path $suffix $sock
